@@ -61,6 +61,7 @@ def command(
     description: str | LocaleBuilder | None = ...,
     default_member_permissions: UndefinedType | int | Permissions = ...,
     dm_enabled: bool = ...,
+    nsfw: bool | None = ...,
 ) -> Callable[[CommandCallbackT | type[ClassCommandProto]], Includable[AppCommandMeta]]:
     ...
 
@@ -74,9 +75,11 @@ def command(
     description: str | LocaleBuilder | None = None,
     default_member_permissions: UndefinedType | int | Permissions = UNDEFINED,
     dm_enabled: bool = True,
-) -> Includable[AppCommandMeta] | Callable[
-    [CommandCallbackT | type[ClassCommandProto]], Includable[AppCommandMeta],
-]:
+    nsfw: bool | None = None,
+) -> (
+    Includable[AppCommandMeta]
+    | Callable[[CommandCallbackT | type[ClassCommandProto]], Includable[AppCommandMeta]]
+):
     if not callback:
         return partial(
             command,
@@ -85,6 +88,7 @@ def command(
             description=description,
             default_member_permissions=default_member_permissions,
             dm_enabled=dm_enabled,
+            nsfw=nsfw,
         )
 
     autocomplete: dict[str, AutocompleteCallbackT] = {}
@@ -99,7 +103,6 @@ def command(
         defaults: dict[str, Any] = {}
 
         for n, v in callback.__dict__.items():
-
             if not isinstance(v, ClassCommandOption):
                 continue
 
@@ -119,10 +122,7 @@ def command(
     elif isfunction(callback):
         callback_func = callback
 
-        for param in sigparse(callback_func):
-            if param is None:
-                continue
-
+        for param in sigparse(callback_func).parameters:
             option = gen_command_option(param)
             if not option:
                 continue
@@ -146,6 +146,7 @@ def command(
         default_member_permissions=default_member_permissions,
         dm_enabled=dm_enabled,
         autocomplete=autocomplete,
+        nsfw=nsfw,
     )
 
 
@@ -171,6 +172,7 @@ def user_command(
     name: str | None = ...,
     default_member_permissions: UndefinedType | int | Permissions = ...,
     dm_enabled: bool = ...,
+    nsfw: bool | None = ...,
 ) -> Callable[[UserCommandCallbackT], Includable[AppCommandMeta]]:
     ...
 
@@ -183,6 +185,7 @@ def user_command(
     name: str | None = None,
     default_member_permissions: UndefinedType | int | Permissions = UNDEFINED,
     dm_enabled: bool = True,
+    nsfw: bool | None = None,
 ) -> Callable[[UserCommandCallbackT], Includable[AppCommandMeta]] | Includable[AppCommandMeta]:
     if not callback:
         return partial(
@@ -191,6 +194,7 @@ def user_command(
             name=name,
             default_member_permissions=default_member_permissions,
             dm_enabled=dm_enabled,
+            nsfw=nsfw,
         )
 
     return register_command(
@@ -201,6 +205,7 @@ def user_command(
         guild=guild,
         default_member_permissions=default_member_permissions,
         dm_enabled=dm_enabled,
+        nsfw=nsfw,
     )
 
 
@@ -216,6 +221,7 @@ def message_command(
     name: str | None = ...,
     default_member_permissions: UndefinedType | int | Permissions = ...,
     dm_enabled: bool = ...,
+    nsfw: bool | None = ...,
 ) -> Callable[[MessageCommandCallbackT], Includable[AppCommandMeta]]:
     ...
 
@@ -228,6 +234,7 @@ def message_command(
     name: str | None = None,
     default_member_permissions: UndefinedType | int | Permissions = UNDEFINED,
     dm_enabled: bool = True,
+    nsfw: bool | None = None,
 ) -> Callable[[MessageCommandCallbackT], Includable[AppCommandMeta]] | Includable[AppCommandMeta]:
     if not callback:
         return partial(
@@ -236,6 +243,7 @@ def message_command(
             name=name,
             default_member_permissions=default_member_permissions,
             dm_enabled=dm_enabled,
+            nsfw=nsfw,
         )
 
     return register_command(
@@ -246,4 +254,5 @@ def message_command(
         guild=guild,
         default_member_permissions=default_member_permissions,
         dm_enabled=dm_enabled,
+        nsfw=nsfw,
     )
